PROJECT {
  NAME       = LUNAR.ftl;
  TITLE      =VelocityLander;
  AUTHOR     = T. Carrico;
  DATEFORMAT = YYYY.DD.MM;
  LASTCHANGE = 2005.09.08;
  CREATED    = 2005.14.04;
  SHELL      = ON_LINE;
  SHELLOPTIONS {
    ONLINE_REFRESHTIME  = 55;
    ONLINE_TIMEOUTCOUNT = 1100;
    ONLINE_CODE         = ON;
    ONLINE_TRACE_BUFFER = (ON, PAR(12));
    COMMENTS            = ON;
    FTL_BUFFER          = (ON, PAR(1));
    PASSWORD            = OFF;
    PUBLIC_IO           = ON;
    FAST_CMBF           = OFF;
    FAST_COA            = ON;
    BTYPE               = DOUBLE;
    C_TYPE              = ANSI;
  } /* SHELLOPTIONS */
  MODEL {
    VARIABLE_SECTION {
      LVAR {
        NAME       = Altitude_delta;
        BASEVAR    = Ft;
        LVRANGE    = MIN(0.0), MAX(1000.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(0.0);
        RESOLUTION = XGRID(100.0), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        EXPLANATION {
          PAR {Vertical distance to moon's surface}
        }
        COLOR      = RED (0), GREEN (128), BLUE (128);
        INPUT      = CMBF;
        POS        = -178, -183;
        TERM {
          TERMNAME = at_alt;
          POINTS   = (0.0, 1.0),
                     (0.10000000000002, 1.0),
                     (50.0, 0.0),
                     (1000.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (255), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = near;
          POINTS   = (0.0, 0.0),
                     (0.10000000000002, 0.0),
                     (50.0, 1.0),
                     (200.0, 0.0),
                     (1000.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (0);
        }
        TERM {
          TERMNAME = far;
          POINTS   = (0.0, 0.0),
                     (50.0, 0.0),
                     (200.0, 1.0),
                     (1000.0, 1.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (0), BLUE (255);
        }
      }  /* LVAR */
      LVAR {
        NAME       = Velocity_delta;
        BASEVAR    = FPS;
        LVRANGE    = MIN(-100.0), MAX(0.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(0.0);
        RESOLUTION = XGRID(10.0), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        EXPLANATION {
          PAR {Lander vertical velocity in meters per second}
        }
        COLOR      = RED (255), GREEN (0), BLUE (0);
        INPUT      = CMBF;
        POS        = -177, -145;
        TERM {
          TERMNAME = VeryFast;
          POINTS   = (-100.0, 1.0),
                     (-75.0, 1.0),
                     (-10.0, 0.0),
                     (0.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (255), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = Fast;
          POINTS   = (-100.0, 0.0),
                     (-75.0, 0.0),
                     (-10.0, 1.0),
                     (-0.10000000000001, 0.0),
                     (0.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (128);
        }
        TERM {
          TERMNAME = Target_V;
          POINTS   = (-100.0, 0.0),
                     (-10.0, 0.0),
                     (-0.10000000000001, 1.0),
                     (0.0, 1.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (128);
        }
      }  /* LVAR */
      LVAR {
        NAME       = Vert_Accel;
        BASEVAR    = ft_per_sec_sqr;
        LVRANGE    = MIN(0.0), MAX(5.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(0.0);
        RESOLUTION = XGRID(0.5), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        EXPLANATION {
          PAR {Lander acceleration in meters per second squared}
        }
        COLOR      = RED (0), GREEN (0), BLUE (255);
        OUTPUT     = COM;
        POS        = 184, -126;
        TERM {
          TERMNAME = Zero;
          POINTS   = (0.0, 0.0),
                     (0.0, 1.0),
                     (2.0, 0.0),
                     (5.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (128), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = small;
          POINTS   = (0.0, 0.0),
                     (2.0, 1.0),
                     (3.0, 0.0),
                     (5.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (0);
        }
        TERM {
          TERMNAME = medium;
          POINTS   = (0.0, 0.0),
                     (2.0, 0.0),
                     (3.0, 1.0),
                     (5.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (128), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = large;
          POINTS   = (0.0, 0.0),
                     (3.0, 0.0),
                     (5.0, 1.0),
                     (5.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (0), BLUE (255);
        }
      }  /* LVAR */
    }  /* VARIABLE_SECTION */

    OBJECT_SECTION {
      RULEBLOCK {
        NAME        = Vertical;
        INPUT       = Altitude_delta, Velocity_delta;
        OUTPUT      = Vert_Accel;
        AGGREGATION = (MIN_MAX, PAR (0.0));
        RESULT_AGGR = BSUM;
        POS         = -15, -146;
        RULES {
          IF    Altitude_delta = at_alt
            AND Velocity_delta = VeryFast
          THEN  Vert_Accel = large   WITH 1.000;
          IF    Altitude_delta = at_alt
            AND Velocity_delta = Fast
          THEN  Vert_Accel = medium   WITH 1.000;
          IF    Altitude_delta = at_alt
            AND Velocity_delta = Target_V
          THEN  Vert_Accel = Zero   WITH 1.000;
          IF    Altitude_delta = near
            AND Velocity_delta = VeryFast
          THEN  Vert_Accel = large   WITH 1.000;
          IF    Altitude_delta = near
            AND Velocity_delta = Fast
          THEN  Vert_Accel = small   WITH 1.000;
          IF    Altitude_delta = near
            AND Velocity_delta = Target_V
          THEN  Vert_Accel = Zero   WITH 1.000;
          IF    Altitude_delta = far
            AND Velocity_delta = VeryFast
          THEN  Vert_Accel = medium   WITH 1.000;
          IF    Altitude_delta = far
            AND Velocity_delta = Fast
          THEN  Vert_Accel = Zero   WITH 1.000;
          IF    Altitude_delta = far
            AND Velocity_delta = Target_V
          THEN  Vert_Accel = Zero   WITH 1.000;
        }  /* RULES */
      }  /* RULEBLOCK */
    }  /* OBJECT_SECTION */
  }  /* MODEL */
}  /* PROJECT */ 
/* fuzzyTECH 5.54k Professional Edition */
/* FT IU 00139 01 ID */
ONLINE {
  TIMESTAMP = 20050809150820UT;
}  /* ONLINE */

NEUROFUZZY {
  LEARNRULE     =RandomMethod;
  STEPWIDTHDOS  = 0.101563;
  STEPWIDTHTERM = 1.000000;
  MAXDEVIATION  = (50.000000, 1.000000, 0.750000);
  AVGDEVIATION  = 0.100000;
  MAXSTEPS      = 100;
  NEURONS       = 1;
  DATASEQUENCE  = RANDOM;
  UPDATEDBGWIN  = OFF;
}  /* NEUROFUZZY */